@@ -1,8 +1,13 @@
-import click
+import glob
 import os
+import pkgutil
 import subprocess
 import time
-import glob
+from math import ceil, floor
+
+import click
+
+from and_cli import NUM_COLS
 
 
 @click.group()
@@ -31,6 +36,11 @@ def run(filename, in_filename):
 
     in_file = open(in_filename, "r") if in_filename in os.listdir() else None
 
+    _print_title(f"[ Input | {in_filename if in_file else 'stdin'} ]")
+    if in_file:
+        click.echo(in_file.read())
+        in_file.seek(0, 0)
+
     run_start = time.time()
     runner = subprocess.run(
         ["./out"], stdin=in_file, check=False, stdout=subprocess.PIPE, text=True
@@ -41,17 +51,10 @@ def run(filename, in_filename):
         return
     run_end = time.time()
 
-    in_file.seek(0, 0)
-    click.echo("=" * 35 + "INPUT" + "=" * 36)
-    click.echo(in_file.read())
-    click.echo("=" * 35 + "OUTPUT" + "=" * 35)
+    _print_title("[ Output | stdout ]")
     click.echo(runner.stdout.strip())
-    click.echo("=" * 76)
-    click.echo(
-        click.style(
-            f"Ran successfully in {run_end - run_start:.4f} seconds", fg="green"
-        )
-    )
+
+    _print_title(f"[ Time | {run_end - run_start:.4f}s ]")
 
     os.remove("out")
 
@@ -88,4 +91,41 @@ def _compile(filename):
             f"Compiled successfully in {compile_end - compile_start:.4f} seconds",
             fg="green",
         )
-    )
\ No newline at end of file
+    )
+
+
+def _print_title(msg):
+    """Prints a message surrounded by '-' to a width of NUM_COLS
+
+    Args:
+        msg (str): The message to format and print
+    """
+    click.echo(
+        "-" * floor((NUM_COLS - len(msg)) / 2)
+        + msg
+        + "-" * ceil((NUM_COLS - len(msg)) / 2)
+    )
+
+
+@_and.command()
+@click.argument(
+    "name",
+    default="new_exercise",
+)
+def init(name):
+    """Creates a new folder with a boilerplate C++ file and in.txt
+
+    NAME will be used for both the folder and C++ file.
+    Default is 'new_exercise'
+    """
+    try:
+        os.mkdir(name)
+    except FileExistsError:
+        click.echo(click.style("A directory with this name already exists", "red"))
+
+    with open(f"{name}/in.txt", "a"):
+        os.utime(f"{name}/in.txt", None)
+
+    template = pkgutil.get_data(__name__, "templates/template.cpp")
+    with open(f"{name}/{name}.cpp", "wb") as f:
+        f.write(template)
